bioneuralnet.clustering.hybrid_louvain — BioNeuralNet 1.0.4 documentation

# bioneuralnet.clustering.hybrid_louvain

Functions

`get_logger`(name) | Retrieves a global logger configured to write to 'bioneuralnet.log' at the project root.

Classes

`CorrelatedLouvain`(G, B[, Y, k3, k4, weight, ...]) | CorrelatedLouvain Class for Community Detection with Correlated Omics Data.
`CorrelatedPageRank`(graph, omics_data, ...[, ...]) | PageRank Class for Clustering Nodes Based on Personalized PageRank.
`HybridLouvain`(G, B, Y[, k3, k4, max_iter, ...]) | HybridLouvain Class that combines Correlated Louvain and Correlated PageRank for community detection.

class bioneuralnet.clustering.hybrid_louvain.HybridLouvain(G: Graph, B: DataFrame, Y: DataFrame, k3: float = 0.2, k4: float = 0.8, max_iter: int = 10, weight: str = 'weight', gpu: bool = False, seed: int | None = None, tune: bool | None = False)

  Bases: `object`

  HybridLouvain Class that combines Correlated Louvain and Correlated PageRank for community detection.

  G

    NetworkX graph object.

    Type:

      nx.Graph

  B

    Omics data.

    Type:

      pd.DataFrame

  Y

    Phenotype data.

    Type:

      pd.DataFrame

  k3

    Weight for Correlated Louvain.

    Type:

      float

  k4

    Weight for Correlated Louvain.

    Type:

      float

  max_iter

    Maximum number of iterations.

    Type:

      int

  weight

    Edge weight parameter name.

    Type:

      str

  tune

    Flag to enable tuning of parameters

    Type:

      bool

  run(as_dfs: bool = False) → dict | list